# Supports Organizer.rb
=begin
Copyright 2009, Author
All Rights Reserved

THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

License:   		Nil

Author:      	Matt666
Organization:   Nil
Name:      		Remove_CG_Mat
Version:   		1.4
SU Version:   	Work on v6 & v7. I don't know on v5
Date:      		30/01/09
Description:   	Remove all materials from a group or a component instance. Possibility to apply G/C material 
				to the inside geometry.
History:
   1.4: 		More speed
				Add the RickW's collaborative effort ;), and support Organizer.rb, of course!

=end

require 'sketchup.rb'

unless file_loaded?(__FILE__)
   file_loaded(__FILE__)
   $submenu ? (organizer = $submenu) : (organizer = UI.menu("Plugins"))
   organizer.add_item("Remove C-G materials"){Remove_CG_mat.tool}
end

module Remove_CG_mat
	def self.tool
		model = Sketchup.active_model
		ents = model.active_entities
		@n = 0
		if Sketchup.version[0,1].to_i >= 7
			model.start_operation("Remove comp & group materials",true)
		else
			model.start_operation("Remove comp & group materials")
		end
		Sketchup.set_status_text "Program is running...", SB_PROMPT
		if UI.messagebox("Would you apply the Group/Component material to the default geometry?", MB_YESNO, "Remove C/G material")==7
			self.boucle ents
		else
			self.put_on_comp_material ents
			self.boucle ents
		end
		Sketchup.set_status_text "Done!", SB_PROMPT
		UI.messagebox("Done! "+@n.to_s+" material components/groups deleted.")
		model.commit_operation
	end
	
	def self.put_on_comp_material(sel)
		for e in sel
			if ["Group","ComponentInstance"].index e.typename
				compEnts = e.entities if e.typename == "Group"
				compEnts = e.definition.entities if e.typename == "ComponentInstance"
				if (e.parent.class == Sketchup::ComponentDefinition) and (not e.material)
					e.material = e.parent.instances[0].material
				end
				self.put_on_comp_material compEnts
			elsif (e.parent.class == Sketchup::ComponentDefinition) and (not e.material)
				material = e.parent.instances[0].material
				e.material = material
				e.back_material = material if e.respond_to? "back_material"
			end
		end
	end
	
	def self.boucle(sel)
		for e in sel
			if ["Group","ComponentInstance"].index e.typename
				compEnts = e.entities if e.typename == "Group"
				compEnts = e.definition.entities if e.typename == "ComponentInstance"
				@n += 1 if e.material
				e.material = nil
				self.boucle compEnts
			end
		end
	end
end